%bcond_with bootstrap

Name:           apache-commons-collections
Version:        3.2.2
Release:        %mkrel 17
Group:          Development/Java
Summary:        Provides new interfaces, implementations and utilities for Java Collections
License:        ASL 2.0
URL:            https://commons.apache.org/collections/
BuildArch:      noarch
#ExclusiveArch:  %{java_arches} noarch

Source0:        https://www.apache.org/dist/commons/collections/source/commons-collections-%{version}-src.tar.gz

Patch0:         0001-Port-to-Java-8.patch
Patch1:         0002-Port-to-OpenJDK-11.patch
Patch2:         0003-Port-to-OpenJDK-21.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
%endif

%description
The introduction of the Collections API by Sun in JDK 1.2 has been a
boon to quick and effective Java programming. Ready access to powerful
data structures has accelerated development by reducing the need for
custom container classes around each core object. Most Java2 APIs are
significantly easier to use because of the Collections API.
However, there are certain holes left unfilled by Sun's
implementations, and the Jakarta-Commons Collections Component strives
to fulfill them. Among the features of this package are:
- special-purpose implementations of Lists and Maps for fast access
- adapter classes from Java1-style containers (arrays, enumerations) to
Java2-style collections.
- methods to test or create typical set-theory properties of collections
such as union, intersection, and closure.

%package testframework
Summary:        Testframework for %{name}
Requires:       %{name} = %{version}-%{release}

%description testframework
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
%{summary}.

%prep
%setup -q -n commons-collections-%{version}-src

# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;
find . -name "*.class" -exec rm -f {} \;

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1

# Port to maven-antrun-plugin 3.0.0
sed -i s/tasks/target/ pom.xml

# Fix file eof
sed -i 's/\r//' LICENSE.txt PROPOSAL.html README.txt NOTICE.txt

%mvn_package :commons-collections-testframework testframework
%mvn_file ':commons-collections{,-testframework}' %{name}@1 commons-collections@1

%build
%mvn_build -- -Dcommons.packageId=collections

%install
%mvn_artifact commons-collections:commons-collections-testframework:%{version} target/commons-collections-testframework-%{version}.jar
%mvn_install

%files -f .mfiles
%doc PROPOSAL.html README.txt
%license LICENSE.txt NOTICE.txt

%files testframework -f .mfiles-testframework

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.2.2-17.mga10
+ Revision: 2223087
- Mageia 10 Mass Rebuild

* Tue May 21 2024 ns80 <ns80> 3.2.2-16.mga10
+ Revision: 2065545
- rebuild for java 21

* Mon Jul 25 2022 neoclust <neoclust> 3.2.2-15.mga9
+ Revision: 1871159
- Disable bootstrap

* Sat Jul 23 2022 neoclust <neoclust> 3.2.2-14.mga9
+ Revision: 1870168
- Fix BR for bootstrap

* Tue Jun 07 2022 neoclust <neoclust> 3.2.2-13.mga9
+ Revision: 1863222
- Add bootstrap mode
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Mar 07 2021 daviddavid <daviddavid> 3.2.2-11.mga9
+ Revision: 1700312
- Backport fix to build with maven-antrun-plugin 3.0.0

* Sun Aug 23 2020 neoclust <neoclust> 3.2.2-10.mga8
+ Revision: 1618233
- Fix build for java11

* Sat Feb 15 2020 umeabot <umeabot> 3.2.2-9.mga8
+ Revision: 1527600
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 3.2.2-8.mga8
+ Revision: 1422326
- Rebuild to regenerate OSGi metadata

* Tue Sep 18 2018 umeabot <umeabot> 3.2.2-7.mga7
+ Revision: 1259671
- Mageia 7 Mass Rebuild

* Wed May 17 2017 neoclust <neoclust> 3.2.2-6.mga6
+ Revision: 1102455
- Fix BuildRequires

* Fri Apr 29 2016 daviddavid <daviddavid> 3.2.2-5.mga6
+ Revision: 1007668
- Add workaround for symlink->directory rpm bug

* Wed Mar 02 2016 neoclust <neoclust> 3.2.2-4.mga6
+ Revision: 982116
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 3.2.2-3.mga6
+ Revision: 975474
- First rebuild of the java stack
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Nov 25 2015 daviddavid <daviddavid> 3.2.2-1.mga6
+ Revision: 906047
- sync with fc24 (update to 3.2.2)
- fixes new deserialization security (mga#17227)

* Sat Dec 27 2014 pterjan <pterjan> 3.2.1-24.mga5
+ Revision: 806411
- Clean rebuild
- Sync with Fedora
+ dmorgan <dmorgan>
- Restore from Obsolete
- Fix Requires into java-headless
+ sander85 <sander85>
- Depends on broken java stack
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sat Jan 11 2014 dmorgan <dmorgan> 3.2.1-17.mga4
+ Revision: 566209
- Disable tests

* Tue Oct 22 2013 umeabot <umeabot> 3.2.1-16.mga4
+ Revision: 545586
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 3.2.1-15.mga4
+ Revision: 501428
- Build with xmvn

* Fri Jan 11 2013 umeabot <umeabot> 3.2.1-14.mga3
+ Revision: 345654
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jul 08 2012 dmorgan <dmorgan> 3.2.1-13.mga3
+ Revision: 268867
- saxon dependency removed - not needed
- minor spec file changes according to the latest guidelines

* Wed Jul 20 2011 dmorgan <dmorgan> 3.2.1-12.mga2
+ Revision: 127185
- Added *-testframework depmap entries.

* Wed Apr 27 2011 dmorgan <dmorgan> 3.2.1-11.mga1
+ Revision: 92225
- Rebuild after bootstrapping
- imported package apache-commons-collections


* Wed Mar 16 2011 Alexander Kurtakov <akurtako@redhat.com> 3.2.1-10
- Drop tomcat5 subpackage.

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.1-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Nov 8 2010 Alexander Kurtakov <akurtako@redhat.com> 3.2.1-8
- Add commons-collections:commons-collections depmap.

* Mon Oct 4 2010 Alexander Kurtakov <akurtako@redhat.com> 3.2.1-7
- Fix pom name.
- Use newer maven plugins names.

* Tue Aug 30 2010 Carl Green <carlgreen at gmail.com> - 3.2.1-6
- Change package to own files in directories, not the directories

* Mon Aug 30 2010 Carl Green <carlgreen at gmail.com> - 3.2.1-5
- Remove source and patches no longer needed for Maven
- Fix non-standard groups and remove empty sections
- Fix file permissions

* Sat Aug 28 2010 Carl Green <carlgreen at gmail.com> - 3.2.1-4
- Renamed from jakarta-commons-collections
- Updated to use maven2
- Replaced saxon:group instruction with xsl:for-each-group in pom-maven2jpp-newdepmap.xsl
